﻿using System;
using System.Drawing;
using System.Globalization;
using System.Windows.Forms;
using FebUtil.Operations;
using GrapeCity.ActiveReports.Data;


namespace FebPrintClassLib.Rpt6
{
    /// <summary>
    /// Summary description for Rpt06_A4p.
    /// </summary>
	public partial class Rpt06_A4p : GrapeCity.ActiveReports.SectionReport
	{
		private XMLDataSource dsrpt = null;
		private Image imgLogoFile = null;

        Rpt06_CircLoad1 rptCircLoad1 = null;
		Rpt06_CircLoad2 rptCircLoad2 = null;
		Rpt06_CircLoad3 rptCircLoad3 = null;
		Rpt06_CircLoad4 rptCircLoad4 = null;
		Rpt06_CircLoad5 rptCircLoad5 = null;
		Rpt06_CircLoad6 rptCircLoad6 = null;
		Rpt06_Kabel rptCable = null;
		Rpt06_Trafo rptTrafo = null;
		Rpt06_VoltDrop rptVoltDrop = null;
		Rpt06_ProtDev1 rptProtDev1 = null;
		Rpt06_FaultCurr rptFaultCurr = null;

        XMLDataSource xmlDS7 = null;
        XMLDataSource xmlDS2 = null;
        XMLDataSource xmlDS3 = null;
        XMLDataSource xmlDS5 = null;
        XMLDataSource xmlDS6 = null;


        public Rpt06_A4p()
		{
			InitializeComponent();
		}

        private string xmlfile = "";

        public string strXmlFile
		{
			get
			{
				return xmlfile;
			}
			set
			{
				xmlfile = value;
			}
		}

		public int iStartPage
		{
			get
			{
				return (int)this.fPageStart.Value;
			}
			set
			{
				this.fPageStart.Value = value - 1;
			}
		}

		public bool bMultiRpt
		{ get; set; }

		private void Rpt06_A4p_ReportStart(object sender, EventArgs e)
		{
			string strLogoFile = "";
            //clItem = new CommonItems();
            this.Document.CacheToDisk = true;

            LblHeadTxt.Text = Properties.Resources.IDS_RappName_6;

			textBox2.BackColor = CommonItems.clBackGround;
			textBox2.ForeColor = CommonItems.clForeGround;

			txtCircuitID1.BackColor = CommonItems.clBackGround;
			txtCircuitID1.ForeColor = CommonItems.clForeGround;

            try
            {
                this.Document.Printer.PrinterName = ""; //use the virtual print driver for paper sizes not supported by the local printer
                this.PageSettings.PaperKind = System.Drawing.Printing.PaperKind.Custom;
                this.Document.Printer.PaperSize = new System.Drawing.Printing.PaperSize("A4", (int)CmToInch(21.0F), (int)CmToInch(29.7F));
            }
            catch (Exception err)
            {

                MessageBox.Show(err.Message, "Papersize error");
            }

            this.PageSettings.DefaultPaperSize = false;
			this.PageSettings.Margins.Bottom = CmToInch(1.0F);
			this.PageSettings.Margins.Left = CmToInch(2.0F);
			this.PageSettings.Margins.Right = CmToInch(1.0F);
			this.PageSettings.Margins.Top = CmToInch(0.6F);
			this.PageSettings.Orientation = GrapeCity.ActiveReports.Document.Section.PageOrientation.Portrait;
			this.PageSettings.PaperHeight = CmToInch(29.7F);
			this.PageSettings.PaperWidth = CmToInch(21.0F);
			this.PrintWidth = CmToInch(17.86F);

			rptCircLoad1 = new Rpt06_CircLoad1();
			rptCircLoad2 = new Rpt06_CircLoad2();
			rptCircLoad3 = new Rpt06_CircLoad3();
			rptCircLoad4 = new Rpt06_CircLoad4();
			rptCircLoad5 = new Rpt06_CircLoad5();
			rptCircLoad6 = new Rpt06_CircLoad6();
			rptCable = new Rpt06_Kabel();
			rptTrafo = new Rpt06_Trafo();
			rptVoltDrop = new Rpt06_VoltDrop();
			rptProtDev1 = new Rpt06_ProtDev1();
			rptFaultCurr = new Rpt06_FaultCurr();

			//Set datasource for report
			try
			{
				dsrpt = new XMLDataSource(this.strXmlFile, "//Circuit");
                //dsrpt.NodeList = (System.Xml.XmlNodeList)((XMLDataSource)this.DataSource).Field("Circuit", true);
                this.DataSource = dsrpt;

                xmlDS2 = new XMLDataSource(this.strXmlFile, "//CircuitLoad");
                xmlDS3 = new XMLDataSource(this.strXmlFile, "//CircuitCable");
                xmlDS5 = new XMLDataSource(this.strXmlFile, "//CircuitTransformer");
                xmlDS6 = new XMLDataSource(this.strXmlFile, "//VoltageDropSpecific");
                xmlDS7 = new XMLDataSource(this.strXmlFile, "//CircuitProtectiveDevice");
                
                strLogoFile = ((XMLDataSource)this.DataSource).Field("../../ProjectData/Contractor/LogoFile", false).ToString();
                if (strLogoFile != ".")
                {
                    if (!string.IsNullOrEmpty(strLogoFile))
                    {
                        imgLogoFile = BitmapService.GetImageForBitmapString(strLogoFile);
                        bmpFirma.Image = imgLogoFile;
                    }
                    else
                        bmpFirma.Visible = false;
                }
                else
                    bmpFirma.Visible = false;
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message);
				return;

			}
		}


		private void detail_Format(object sender, EventArgs e)
		{
			
		}

		private void groupCircTxt_Format(object sender, EventArgs e)
		{
            string txt0 = "";
            string txt1 = "";
            string txt2 = "";
            string txt3 = "";

            //txt0
            if (((XMLDataSource)this.DataSource).Field("CircuitProtectionElectricalSeparation", false).ToString() == "1")
                txt0 = String.Format("{0}\t:", FebPrintClassLib.Properties.Resources.IDS_CIRCTXT_1) + "\n";
            else if (((XMLDataSource)this.DataSource).Field("CircuitProtectionElectricalSeparation", false).ToString() == "-1")
                txt0 = "";
            else if (((XMLDataSource)this.DataSource).Field("CircuitMaxDisconnectingTimeEarthFault", false).ToString() == "-1")
                txt0 = "";
            else
                txt0 = String.Format("{0}\t: {1}", FebPrintClassLib.Properties.Resources.IDS_CIRCTXT_2,
                    ((XMLDataSource)this.DataSource).Field("CircuitMaxDisconnectingTimeEarthFault", false).ToString()) + "\n";
            //txt1
            if (((XMLDataSource)this.DataSource).Field("CircuitProtectionTouchVoltage25V", false).ToString() == "1")
                txt1 = FebPrintClassLib.Properties.Resources.IDS_CIRCTXT_3 + "\n";
            else
                txt1 = "";



            string txtId;
            if (((XMLDataSource)this.DataSource).Field("CircuitSurgeProtectiveDeviceReferenceDesignation", false).ToString() != ".")
                txtId = " (ID: " + ((XMLDataSource)this.DataSource).Field("CircuitSurgeProtectiveDeviceReferenceDesignation", false).ToString() + ")";
            else
                txtId = "";

            if (((XMLDataSource)this.DataSource).Field("CircuitSurgeProtectiveDevice", false).ToString() == "0")
                txt1 += FebPrintClassLib.Properties.Resources.IDS_Spd1 + txtId + "\n";
            else if (((XMLDataSource)this.DataSource).Field("CircuitSurgeProtectiveDevice", false).ToString() == "1")
                txt1 += FebPrintClassLib.Properties.Resources.IDS_Spd2 + txtId + "\n";
            else if (((XMLDataSource)this.DataSource).Field("CircuitSurgeProtectiveDevice", false).ToString() == "2")
                txt1 += FebPrintClassLib.Properties.Resources.IDS_Spd3 + txtId + "\n";
            else if (((XMLDataSource)this.DataSource).Field("CircuitSurgeProtectiveDevice", false).ToString() == "3")
                txt1 += FebPrintClassLib.Properties.Resources.IDS_Spd4 + txtId + "\n";
            else if (((XMLDataSource)this.DataSource).Field("CircuitSurgeProtectiveDevice", false).ToString() == "4")
                txt1 += FebPrintClassLib.Properties.Resources.IDS_Spd5 + txtId + "\n";

            //txt2
            if (((XMLDataSource)this.DataSource).Field("CircuitProtectiveDeviceBreakPE", false).ToString() == "1" &&
                ((XMLDataSource)this.DataSource).Field("CircuitProtectiveDeviceEachConductor", false).ToString() == "1")
                txt2 = FebPrintClassLib.Properties.Resources.IDS_CIRCTXT_4 + "\n";
            else if (((XMLDataSource)this.DataSource).Field("CircuitProtectiveDeviceEachConductor", false).ToString() == "1")
                txt2 = FebPrintClassLib.Properties.Resources.IDS_CIRCTXT_5 + "\n";
            else
                txt2 = "";

            //txt3
            if (((XMLDataSource)this.DataSource).Field("CircuitShortCircuitAndEarthFaultProof", false).ToString() == "0")
                txt3 = "";
            else if (((XMLDataSource)this.DataSource).Field("CircuitShortCircuitAndEarthFaultProof", false).ToString() == "1")
                txt3 = FebPrintClassLib.Properties.Resources.txt_CircuitShortCircuitAndEarthFaultProof + "\n";
            else
                txt3 = "";

            txtCirctxt0.Text = txt0 + txt1 + txt2 + txt3;


            if (((XMLDataSource)this.DataSource).Field("CircuitShallBeProtectedByRCD", false).ToString() == "1")
                txt4.Text = FebPrintClassLib.Properties.Resources.IDS_CIRCTXT_6;
            else if (((XMLDataSource)this.DataSource).Field("CircuitShallBeProtectedByRCD", false).ToString() == "0")
                txt4.Text = FebPrintClassLib.Properties.Resources.IDS_CIRCTXT_7;
            else
                txt4.Text = "";

            if (((XMLDataSource)this.DataSource).Field("CircuitTerminalNumber", false).ToString() != ".")
            {
                txtRekkeklemme.Text = String.Format("{0}", FebPrintClassLib.Properties.Resources.IDS_REKKEKLEMME_TXT);
                txt5.Text = String.Format("{0}", ((XMLDataSource)this.DataSource).Field("CircuitTerminalNumber", false).ToString());
                textCol2.Visible = true;
            }
            else
            {
                txtRekkeklemme.Text = "";
                textCol2.Visible = false;
            }


            if (((XMLDataSource)this.DataSource).Field("BusbarTrunkingTapOffDistance", false).ToString() != "999999")
            {
                //TapOff distance from feeding point
                txtBBTDist.Text = String.Format("{0}", FebPrintClassLib.Properties.Resources.IDS_BBT_TEXT);

                //txtBBTValue.Text = String.Format("{0}", ((XMLDataSource)this.DataSource).Field("BusbarTrunkingTapOffDistance", false).ToString());
                try
                {
                    txtBBTValue.Text = String.Format("{0:#0.00}",
                     Convert.ToDouble(((XMLDataSource)this.DataSource).Field("BusbarTrunkingTapOffDistance", false), CultureInfo.InvariantCulture));
                }
                catch (Exception)
                {
                    txtBBTValue.Text = "";
                }


                txtBBTDist.Visible = true;
                txtBBTValue.Visible = true;
                txtBBTColon.Visible = true;
            }
            else
            {
                txtBBTDist.Visible = false;
                txtBBTValue.Visible = false;
                txtBBTColon.Visible = false;
            }


        }

        private void groupCircLoad_Format(object sender, EventArgs e)
		{
			//CircLoad
			xmlDS2.NodeList = (System.Xml.XmlNodeList)((XMLDataSource)this.DataSource).Field("CircuitLoad", true);

            if ((xmlDS2).Field("CircuitLoadType", false).ToString() == "1" ||
                  (xmlDS2).Field("CircuitLoadType", false).ToString() == "2" ||
                  (xmlDS2).Field("CircuitLoadType", false).ToString() == "3" ||
                  (xmlDS2).Field("CircuitLoadType", false).ToString() == "4")
            {
                rptCircLoad1.DataSource = xmlDS2;
                subCircLoad.Report = rptCircLoad1;
                subCircLoad.Visible = true;
            }
            else if ((xmlDS2).Field("CircuitLoadType", false).ToString() == "0")
            {
                rptCircLoad2.DataSource = xmlDS2;
                subCircLoad.Report = rptCircLoad2;
            }
            else if ((xmlDS2).Field("CircuitLoadType", false).ToString() == "5" ||
                    (xmlDS2).Field("CircuitLoadType", false).ToString() == "6" ||
                    (xmlDS2).Field("CircuitLoadType", false).ToString() == "7" ||
                    (xmlDS2).Field("CircuitLoadType", false).ToString() == "10" ||
                    (xmlDS2).Field("CircuitLoadType", false).ToString() == "8")
            {
                rptCircLoad3.DataSource = xmlDS2;
                subCircLoad.Report = rptCircLoad3;
                subCircLoad.Visible = true;
            }
            else if ((xmlDS2).Field("CircuitLoadType", false).ToString() == "9")
            {
                rptCircLoad4.DataSource = xmlDS2;
                subCircLoad.Report = rptCircLoad4;
                subCircLoad.Visible = true;
            }
            else if ((xmlDS2).Field("CircuitLoadType", false).ToString() == "11") //BBT
            {
                rptCircLoad5.DataSource = xmlDS2;
                subCircLoad.Report = rptCircLoad5;
                subCircLoad.Visible = true;
            }
            else if ((xmlDS2).Field("CircuitLoadType", false).ToString() == "12") //Generator
            {
                rptCircLoad6.DataSource = xmlDS2;
                subCircLoad.Report = rptCircLoad6;
                subCircLoad.Visible = true;
            }
            else
                subCircLoad.Visible = false;
		}

		private void groupCable_Format(object sender, EventArgs e)
		{
			//Cable
			xmlDS3.NodeList = (System.Xml.XmlNodeList)((XMLDataSource)this.DataSource).Field("CircuitCable", true);
			rptCable.DataSource = xmlDS3;

			//Cable
			if (((XMLDataSource)this.DataSource).Field("CircuitCableExists", false).ToString() == "0")
			{
				subCable.Visible = false;
				groupCable.Visible = false;
			}
			else
			{
                subCable.Report = rptCable;
                groupCable.Visible = true;
				subCable.Visible = true;
			}
		}

		private void groupUps_Format(object sender, EventArgs e)
		{
            string upsPath = "./CircuitUPS/";

			//Ups
			if (((XMLDataSource)this.DataSource).Field("CircuitUpsExists", false).ToString() == "0")
				groupUps.Visible = false;
			else
                groupUps.Visible = true;

            //txtUpsReferenceDesignation "UpsReferenceDesignation"
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsReferenceDesignation", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsReferenceDesignation", false).ToString() == "-1")
                txtUpsReferenceDesignation.Text = "";
            else
                txtUpsReferenceDesignation.Text = ((XMLDataSource)this.DataSource).Field(upsPath + "UpsReferenceDesignation", false).ToString();
            //
            //txtUpsManufacturer
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsManufacturer", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsManufacturer", false).ToString() == "-1")
                txtUpsManufacturer.Text = "";
            else
                txtUpsManufacturer.Text = ((XMLDataSource)this.DataSource).Field(upsPath + "UpsManufacturer", false).ToString();

            //txtUpsRatedVoltagePrimary
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedVoltagePrimary", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedVoltagePrimary", false).ToString() == "-1")
                txtUpsRatedVoltagePrimary.Text = "";
            else
                txtUpsRatedVoltagePrimary.Text = String.Format("{0:#0.0} V",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedVoltagePrimary", false), CultureInfo.InvariantCulture));

            //txtUpsRatedVoltageSecondary
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedVoltageSecondary", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedVoltageSecondary", false).ToString() == "-1")
                txtUpsRatedVoltageSecondary.Text = "";
            else
                txtUpsRatedVoltageSecondary.Text = String.Format("{0:#0.0} V",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedVoltageSecondary", false), CultureInfo.InvariantCulture));

            //txtUpsShortCircuitInstantaneousCurrent
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitInstantaneousCurrent", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitInstantaneousCurrent", false).ToString() == "-1")
                txtUpsShortCircuitInstantaneousCurrent.Text = "";
            else
                txtUpsShortCircuitInstantaneousCurrent.Text = String.Format("{0:#0.0} A",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitInstantaneousCurrent", false), CultureInfo.InvariantCulture));

            //txtUpsShortCircuitInstantaneousTime
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitInstantaneousTime", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitInstantaneousTime", false).ToString() == "-1")
                txtUpsShortCircuitInstantaneousTime.Text = "";
            else
                txtUpsShortCircuitInstantaneousTime.Text = String.Format("{0:#0.0} s",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitInstantaneousTime", false), CultureInfo.InvariantCulture));

            //txtUpsThermalOverloadLimit
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsThermalOverloadLimit", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsThermalOverloadLimit", false).ToString() == "-1")
                txtUpsThermalOverloadLimit.Text = "";
            else
                txtUpsThermalOverloadLimit.Text = String.Format("{0:#0.0} A",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsThermalOverloadLimit", false), CultureInfo.InvariantCulture));

            //txtUpsRatedTotalPower
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedTotalPower", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedTotalPower", false).ToString() == "-1")
                txtUpsRatedTotalPower.Text = "";
            else
                txtUpsRatedTotalPower.Text = String.Format("{0:#0.0} kVA",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedTotalPower", false), CultureInfo.InvariantCulture));

            //txtUpsTypeDesignation
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsTypeDesignation", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsTypeDesignation", false).ToString() == "-1")
                txtUpsTypeDesignation.Text = "";
            else
                txtUpsTypeDesignation.Text = ((XMLDataSource)this.DataSource).Field(upsPath + "UpsTypeDesignation", false).ToString();

            //txtUpsRatedCurrentPrimary
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedCurrentPrimary", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedCurrentPrimary", false).ToString() == "-1")
                txtUpsRatedCurrentPrimary.Text = "";
            else
                txtUpsRatedCurrentPrimary.Text = String.Format("{0:#0.0} A",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedCurrentPrimary", false), CultureInfo.InvariantCulture));

            //txtUpsRatedCurrentSecondary
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedCurrentSecondary", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedCurrentSecondary", false).ToString() == "-1")
                txtUpsRatedCurrentSecondary.Text = "";
            else
                txtUpsRatedCurrentSecondary.Text = String.Format("{0:#0.0} A",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedCurrentSecondary", false), CultureInfo.InvariantCulture));

            //txtUpsShortCircuitShortTimeCurrent
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitShortTimeCurrent", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitShortTimeCurrent", false).ToString() == "-1")
                txtUpsShortCircuitShortTimeCurrent.Text = "";
            else
                txtUpsShortCircuitShortTimeCurrent.Text = String.Format("{0:#0.0} A",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitShortTimeCurrent", false), CultureInfo.InvariantCulture));

            //txtUpsShortCircuitShortTimeTime
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitShortTimeTime", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitShortTimeTime", false).ToString() == "-1")
                txtUpsShortCircuitShortTimeTime.Text = "";
            else
                txtUpsShortCircuitShortTimeTime.Text = String.Format("{0:#0.0} s",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsShortCircuitShortTimeTime", false), CultureInfo.InvariantCulture));

            //txtUpsStaticSwitchI2t 
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsStaticSwitchI2t", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsStaticSwitchI2t", false).ToString() == "-1")
            {
                txtUpsStaticSwitchI2t.Text = "";
                lblUpsStaticSwitchI2t.Visible = false;
                lbl2UpsStaticSwitchI2t.Visible = false;
            }
            else
            {
                txtUpsStaticSwitchI2t.Text = String.Format("{0:#0} A2s",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsStaticSwitchI2t", false), CultureInfo.InvariantCulture));

                //txtUpsStaticSwitchI2t.Text = ((XMLDataSource)this.DataSource).Field("UpsStaticSwitchI2t", false).ToString();
                lblUpsStaticSwitchI2t.Visible = true;
                lbl2UpsStaticSwitchI2t.Visible = true;
            }

            //txtCircuitIdStaticSwitch
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsStaticSwitchSeparateFeeder", false).ToString() == "0" ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsStaticSwitchFeederCircuitId", false).ToString() == ".")
            {
                txtCircuitIdStaticSwitch.Text = "";
                lblCircuitIdStaticSwitch.Visible = false;
                lbl2CircuitIdStaticSwitch.Visible = false;
            }
            else
            {
                lblCircuitIdStaticSwitch.Visible = true;
                lbl2CircuitIdStaticSwitch.Visible = true;
                txtCircuitIdStaticSwitch.Text = ((XMLDataSource)this.DataSource).Field(upsPath + "UpsStaticSwitchFeederCircuitId", false).ToString();
            }

            //txtCosphi
            if (((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedPowerFactor", false).ToString() == "." ||
                ((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedPowerFactor", false).ToString() == "-1")
                txtCosphi.Text = "";
            else
                txtCosphi.Text = String.Format("{0:#0.00}",
                    Convert.ToDouble(((XMLDataSource)this.DataSource).Field(upsPath + "UpsRatedPowerFactor", false), CultureInfo.InvariantCulture));
        }

        private void groupTrafo_Format(object sender, EventArgs e)
		{
			//Trafo
			xmlDS5.NodeList = (System.Xml.XmlNodeList)((XMLDataSource)this.DataSource).Field("CircuitTransformer", true);
			rptTrafo.DataSource = xmlDS5;

			//Trafo
			if (((XMLDataSource)this.DataSource).Field("CircuitTransformerExists", false).ToString() == "0")
			{
				groupTrafo.Visible = false;
				subTrafo.Visible = false;
			}
			else
			{
                subTrafo.Report = rptTrafo;
                groupTrafo.Visible = true;
				subTrafo.Visible = true;
			}
		}

		private void groupVoltDrop_Format(object sender, EventArgs e)
		{
			//VoltDrop
			xmlDS6.NodeList = (System.Xml.XmlNodeList)((XMLDataSource)this.DataSource).Field("VoltageDrop/VoltageDropSpecific", true);
			rptVoltDrop.DataSource = xmlDS6;

			//Voltagedrop VoltageDropExists
			if (((XMLDataSource)this.DataSource).Field("VoltageDropExists", false).ToString() == "0")
			{
				groupVoltDrop.Visible = false;
				subVoltDrop.Visible = false;
			}
			else
			{
                subVoltDrop.Report = rptVoltDrop;
                groupVoltDrop.Visible = true;
				subVoltDrop.Visible = true;
			}
		}

		private void groupProtDevice_Format(object sender, EventArgs e)
		{
            //ProtDev1
            xmlDS7.NodeList = (System.Xml.XmlNodeList)((XMLDataSource)this.DataSource).Field("CircuitProtectiveDevice", true);
            rptProtDev1.DataSource = xmlDS7;

            //ProtDev1 CircuitProtectiveDeviceExists
            if (((XMLDataSource)this.DataSource).Field("CircuitProtectiveDeviceExists", false).ToString() == "0")
            {
                groupProtDevice.Visible = false;
                subProtDev1.Visible = false;
            }
            else
            {
                subProtDev1.Report = rptProtDev1;
                groupProtDevice.Visible = true;
                subProtDev1.Visible = true;
            }
        }

		private void Rpt06_A4p_ReportEnd(object sender, EventArgs e)
		{
			rptCircLoad1.Document.Dispose();
			rptCircLoad2.Document.Dispose();
			rptCircLoad3.Document.Dispose();
			rptCircLoad4.Document.Dispose();
			rptCircLoad5.Document.Dispose();
			rptCircLoad6.Document.Dispose();
			rptCable.Document.Dispose();
			rptTrafo.Document.Dispose();
			rptVoltDrop.Document.Dispose();
            rptProtDev1.Document.Dispose();
            rptFaultCurr.Document.Dispose();

            rptCircLoad1.Dispose();
            rptCircLoad2.Dispose();
            rptCircLoad3.Dispose();
            rptCircLoad4.Dispose();
            rptCircLoad5.Dispose();
            rptCircLoad6.Dispose();
            rptCable.Dispose();
            rptTrafo.Dispose();
            rptVoltDrop.Dispose();
            rptProtDev1.Dispose();
            rptFaultCurr.Dispose();

            rptCircLoad1 = null;
            rptCircLoad2 = null;
            rptCircLoad3 = null;
            rptCircLoad4 = null;
            rptCircLoad5 = null;
            rptCircLoad6 = null;
            rptCable = null;
            rptTrafo = null;
            rptVoltDrop = null;
            rptProtDev1 = null;
            rptFaultCurr = null;

            GC.Collect();
            GC.WaitForPendingFinalizers();
        }

		private void pageFooter_Format(object sender, EventArgs e)
		{
			if (CommonItems.strLicCountry.Contains("UK")) // DesignGenie
				bmpFebdokLogo.Image = FebPrintClassLib.Properties.Resources.DesignGenie;
			else
				bmpFebdokLogo.Image = FebPrintClassLib.Properties.Resources.febdok_logo;

			if (bMultiRpt)
				txtPageNo.Text = String.Format("({0})", (int)this.fPageStart.Value + this.PageNumber);

			//
			////txtSystemNek 
			//if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Installation/DesignBasis", false).ToString() != ".")
			//    txtSystemNek.Text = ((XMLDataSource)this.DataSource).Field("../../ProjectData/Installation/DesignBasis", false).ToString();


			string str1 = "";
			string str2 = "";
			//txtInstStreet
			//../../ProjectData/Installation/StreetName
			if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Installation/StreetName", false).ToString() == ".")
				str1 = "";
			else
				str1 = ((XMLDataSource)this.DataSource).Field("../../ProjectData/Installation/StreetName", false).ToString();

			//txtInstStreetNo
			//../../ProjectData/Installation/StreetNumber
			if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Installation/StreetNumber", false).ToString() == ".")
				str2 = "";
			else
				str2 = ((XMLDataSource)this.DataSource).Field("../../ProjectData/Installation/StreetNumber", false).ToString();
			txtInstStreet.Text = String.Format("{0} {1}", str1, str2);
			str1 = str2 = "";
			//../../ProjectData/Installation/PostalCode
			//txtInstPostCode
			if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Installation/PostalCode", false).ToString() == ".")
				str1 = "";
			else
				str1 = ((XMLDataSource)this.DataSource).Field("../../ProjectData/Installation/PostalCode", false).ToString();

			//../ProjectData/Installation/PostalDistrict
			//txtInstCity
			if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Installation/PostalDistrict", false).ToString() == ".")
				str2 = "";
			else
				str2 = ((XMLDataSource)this.DataSource).Field("../../ProjectData/Installation/PostalDistrict", false).ToString();
			txtInstPostTown.Text = String.Format("{0} {1}", str1, str2);
			str1 = str2 = "";

			//../../ProjectData/Installation/Name
			//txtInstName
			if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Installation/Name", false).ToString() == ".")
				txtInstName.Text = "";

			//../../ProjectData/Contractor/Name
			//txtCtrName
			if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Contractor/Name", false).ToString() == ".")
				txtCtrName.Text = "";

			//../ProjectData/Contractor/Department
			//txtCtrDep
			if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Contractor/Department", false).ToString() == ".")
				txtCtrDep.Text = "";

			//../../ProjectData/Contractor/StreetAddress
			//txtCtrStreet
			if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Contractor/StreetAddress", false).ToString() == ".")
				txtCtrStreet.Text = "";

			//../../ProjectData/Contractor/PostalCode
			//txtCtrPostalCode
			if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Contractor/PostalCode", false).ToString() == ".")
				str1 = "";
			else
				str1 = ((XMLDataSource)this.DataSource).Field("../../ProjectData/Contractor/PostalCode", false).ToString();

			//../../ProjectData/Contractor/PostalDistrict
			//txtCtrCity
			if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Contractor/PostalDistrict", false).ToString() == ".")
				str2 = "";
			else
				str2 = ((XMLDataSource)this.DataSource).Field("../../ProjectData/Contractor/PostalDistrict", false).ToString();
			txtCtrPostalTown.Text = String.Format("{0} {1}", str1, str2);
			str1 = str2 = "";

			//../../ProjectData/Contractor/PhoneNumber
			//txtCtrPhone
			if (((XMLDataSource)this.DataSource).Field("../../ProjectData/Contractor/PhoneNumber", false).ToString() == ".")
				str1 = "";
			else
				str1 = ((XMLDataSource)this.DataSource).Field("../../ProjectData/Contractor/PhoneNumber", false).ToString();
			txtCtrPhone.Text = string.Format(FebPrintClassLib.Properties.Resources.IDS_PHONE_TXT, str1);
		}

		private void groupHeader2_Format(object sender, EventArgs e)
		{
			if (((XMLDataSource)this.DataSource).Field("../ReferenceDesignation", false).ToString() != "-1" &&
				((XMLDataSource)this.DataSource).Field("../ReferenceDesignation", false).ToString() != ".")
				txtRefDes.Text = ((XMLDataSource)this.DataSource).Field("../ReferenceDesignation", false).ToString();
			else
				txtRefDes.Text = "";

			txtDistributionBoardKind.Text = CommonItems.GetDistrBoardKind(((XMLDataSource)this.DataSource).Field("../DistributionBoardKind", false).ToString());


			//txtSystemVolt {NominalVoltage} V  {3DistributionType}
			if (((XMLDataSource)this.DataSource).Field("../NominalVoltage", false).ToString() != "-1" &&
				((XMLDataSource)this.DataSource).Field("../DistributionType", false).ToString() != ".")
				txtSystemVolt.Text = String.Format("{0} V {1}",
					((XMLDataSource)this.DataSource).Field("../NominalVoltage", false).ToString(),
					((XMLDataSource)this.DataSource).Field("../DistributionType", false).ToString());

			////txtSystemNek 
			if (((XMLDataSource)this.DataSource).Field("DesignBasis", false).ToString() != ".")
				txtSystemNek.Text = ((XMLDataSource)this.DataSource).Field("DesignBasis", false).ToString();

			string ford = txtRefDes.Text;//((GrapeCity.ActiveReports.Data.XMLDataSource)this.DataSource).Field("../ReferenceDesignation", false).ToString();
			groupHeader2.AddBookmark(Properties.Resources.IDS_RappName_6 + "\\" + ford);

		}

        private void groupFaultCurr_Format(object sender, EventArgs e)
        {
            //Set xml-data for subreports with current record/node
            //FaultCurrent
            XMLDataSource xmlDS8 = new XMLDataSource(this.strXmlFile, "//FaultCurrent");
            xmlDS8.NodeList = (System.Xml.XmlNodeList)((XMLDataSource)this.DataSource).Field("CircuitFaultCurrents/FaultCurrent", true);

            rptFaultCurr.DataSource = xmlDS8;
            subFaultCurr.Report = rptFaultCurr;

            //PointF ptNext = new PointF();
            //ptNext.X = subCircLoad.Location.X;
            //ptNext.Y = subCircLoad.Location.Y + subCircLoad.Height + CmToInch(0.2f);

            //FaultCurr CircuitFaultCurrentsExists
            if (((XMLDataSource)this.DataSource).Field("CircuitFaultCurrentsExists", false).ToString() == "0")
                subFaultCurr.Visible = false;
            else
            {
                subFaultCurr.Visible = true;
                //subFaultCurr.Location = ptNext;
            }
        }
    }
}
